@@ -11,7 +11,7 @@
 #include "proc_mem.h"
 #endif
 
-#define VERSION "1.3.5"
+#define VERSION "1.3.6"
 
 //#define DEBUGPRINT 1
 
@@ -268,8 +268,9 @@ const char* ERR_BAM_SORT="\nError: the input alignment file is not sorted!\n";
    FILE* f=fopen(guidegff.chars(),"r");
    if (f==NULL) GError("Error: could not open reference annotation file (%s)!\n",
        guidegff.chars());
-   //                transcripts_only    sort gffr->gfflst by loc?
-   GffReader gffr(f,       true,                   true); //loading only recognizable transcript features
+   //                transcripts_only    sort by location?
+   GffReader gffr(f,       true,             true); //loading only recognizable transcript features
+   gffr.setRefAlphaSorted(); //alphabetical sorting of refseq IDs
    gffr.showWarnings(verbose);
    //        keepAttrs    mergeCloseExons   noExonAttrs
    gffr.readAll(false,          true,        true);
@@ -522,12 +523,12 @@ if (tstackSize<DEF_TSTACK_SIZE) defStackSize=DEF_TSTACK_SIZE;
 			}
 			waitMutex.unlock();
 			haveBundles.notify_one();
-			this_thread::yield();
+			current_thread::yield();
 			queueMutex.lock();
 			while (bundleQueue.Count()==qCount) {
 				queueMutex.unlock();
 				haveBundles.notify_one();
-				this_thread::yield();
+				current_thread::yield();
 				queueMutex.lock();
 			}
 			queueMutex.unlock();
@@ -747,19 +748,18 @@ if(!mergeMode) {
 		int nl;
 		int istr;
 		int tlen;
-		float tcov;
+		double tcov;
 		//float fpkm;
-		float calc_fpkm;
-		float calc_tpm;
+		double calc_fpkm;
+		double calc_tpm;
 		int t_id;
 		while(fgetline(linebuf,linebuflen,ftmp_in)) {
-			//sscanf(linebuf,"%d %d %d %g %g", &nl, &tlen, &t_id, &fpkm, &tcov);
-			sscanf(linebuf,"%d %d %d %d %g", &istr, &nl, &tlen, &t_id, &tcov);
+			sscanf(linebuf,"%d %d %d %d %lf", &istr, &nl, &tlen, &t_id, &tcov);
 			//for the rare cases tcov < 0, invert it ??
 			//if (tcov<0) tcov=-tcov; //should not happen
-			if (tcov<0) tcov=0;
-			calc_fpkm=tcov*1000000000/Frag_Len;
-			calc_tpm=tcov*1000000/Cov_Sum;
+			if (tcov<=0.0) tcov=0.0;
+			calc_fpkm=tcov*1000000000.0/Frag_Len;
+			calc_tpm=tcov*1000000.0/Cov_Sum;
 			if(istr) { // this is a transcript
 				if (ballgown && t_id>0) {
 					guides_RC_tdata[t_id-1]->fpkm=calc_fpkm;
@@ -1163,11 +1163,11 @@ void noMoreBundles() {
 		  if (areThreadsWaiting) {
 		    DBGPRINT("##> NOTIFY ALL workers: no more data!\n");
 		    haveBundles.notify_all();
-		    this_thread::sleep_for(chrono::milliseconds(10));
+		    current_thread::sleep_for(10);
 		    waitMutex.lock();
 		     areThreadsWaiting=(threadsWaiting>0);
 		    waitMutex.unlock();
-		    this_thread::sleep_for(chrono::milliseconds(10));
+		    current_thread::sleep_for(10);
 		  }
 		} while (areThreadsWaiting); //paranoid check that all threads stopped waiting
 #else
@@ -1298,7 +1298,7 @@ void workerThread(GThreadData& td) {
 		queueMutex.unlock();
 		waitMutex.unlock();
 		haveThreads.notify_one(); //in case main thread is waiting
-		this_thread::yield();
+		current_thread::yield();
 		queueMutex.lock();
 		while (bundleWork && bundleQueue->Count()==0) {
 		    haveBundles.wait(queueMutex);//unlocks queueMutex and wait until notified
@@ -1321,7 +1321,7 @@ void workerThread(GThreadData& td) {
 				dataClear.Push(readyBundle->idx);
 				dataMutex.unlock();
 				haveClear.notify_one(); //inform main thread
-				this_thread::yield();
+				current_thread::yield();
 				queueMutex.lock();
 				DBGPRINT2("---->> Thread%d locked back queueMutex\n", td.thread->get_id());
 
